
#ifdef S500API_NEO_EXPORTS
#define S500API_NEO __declspec(dllexport) 
#else
#define S500API_NEO __declspec(dllimport) 
#endif

#ifndef S500API_NEO_H_
#define S500API_NEO_H_

class S500API_NEO PowerMonitor{
public:
//Constructor for PowerMonitor class.
//Parameter is a std::string representing the serial port. For example, "COM7" on a Windows system
//The constructor flushes the device buffer, and opens the serial port.
 PowerMonitor(char* sPort);

//Destructor for PowerMonitor class. 
//The destructor closes the com port.
 ~PowerMonitor();

//Open the serial port. 
//This function returns true if the serial port has been opened, and false if an error occurred. 
//It is not necessary to call this function if the constructor has already been called.
 bool open();

//Close the serial port. 
//This function returns true if the serial port has been closed, and false if an error occurred.
//It is not necessary to call this function if a destructor is being called.
 bool close();

//Detect whether the serial port is open or not. 
//This function returns true of the serial port is open, and false if it is not.
 bool isOpen();

//Flush the device buffer. 
//This function returns true of the buffer has been flushed, and false if an error occurred.
 bool flush();

//get information for the last error that occurred
//This function returns a string which contains a date/timestamp and a description of the error.
char* getLastError();

//Get the current power reading for the device. 
//The function returns a double type number with the reading for the current power measurement setting (dB or dBm). 
//Returns 100 if an error occurs, or if the device is not licensed.
 double getPower();

//Get the sampling rate of the device. 
//The function returns a char f for fast, s for slow, 
//f if an error occurred, or s if the device is not licensed.
 char getSampleRate();

//Set the sampling rate for the device. 
//The function takes a char for the parameter, 'f'for fast, and 's'for slow mode. 
//The function returns true if the command was successfully sent to the device, and false if not.
 bool setSampleRate(char);

//Get the current wavelength setting for the device. 
//The function returns the value, in nanometers, as n integer.
//If the device is not licensed, or an error occurs, the function returns 0.
 int getWavelength();

//Set the wavelength for the device. 
//The function takes a string as a parameter, the wavelength, in nanometers. 
//The function returns true if the command was successfully sent to the device, and false if not.
 bool setWavelength(int);

//Get the current polarization mode for the device. The function returns a string "p1"or "p2"
//If an error occurs, the device is not licensed, or the device does not have 
//polarization modes, the function will return the string "error"
 char* getPolarization();

//Set the polarization mode for the device. 
//The function takes a string as a parameter, "p1"or "p2"
//The function returns true if the command was successfully sent to the device, false if not.
 bool setPolarization(char* pPolar);

//Get the current power measurement mode.  
//The function returns a string "rel"for relative (dB), or "abs"for absolute (dBm). 
//If an error occurs, the function will return the string "error" 
//If the device is not licensed, the function will return the string "not licensed"
 char* getMode();

//Set the power measurement mode for the device. 
//The function takes a string as a parameter, "abs" for absolute power measurement(dBm) and "rel" for relative power measurement (dB). 
//The function returns true if the command was successfully sent to the device, and false if not.
 bool setMode(char* sMode);

//Get the model number for the device.
//The function returns a string with the 10-digit model number. 
//If an error occurs, the function will return the string "error" 
//If the device is not licensed, the function will return the string "not licensed"
char* getModel();

//Get the serial number for the device. 
//The function returns a string with the 9-digit serial number. 
//If an error occurs, the function will return the string "error"
 char* getSerial();

//Get the channel for the array device. If the device is a single channel Series 500
//the function will return 1. If the device is not licensed, or an error occurs, 
//the function will return 0.
 int getChannel();

//Get versions for the device hardware and firmware. 
//The function returns a string with the hardware and firmware information.
//If an error occurs, the function will return the string "error" 
//If the device is not licensed, the function will return the string "not licensed"
 char* getRevInfo();

//Get the battery power for the device. 
//The function returns the battery power, in mV, as an integer. 
//If the device is not licensed, or an error occurs, the function returns 0
 int getBatteryPower();

 //Set licensed file directory for the device. 
//The function takes a string as a parameter
//The function returns true if the command was successfully sent to the device, false if not.
 bool setLicenseFilePath(char* pPath);
 
 //Detect whether current device is licensed or not
 //This function returns true if it's licensed, false if it's not
 bool isLicensed();
private:
	bool checkLicensed();
class PowerMonitorPimpl;

PowerMonitorPimpl *pimpl;
};

//Open the serial port. This function must be called before any other functions.
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//This function returns 1 if the serial port is successfully opened, 0 if an error occurred. 
//It is necessary to call this function before calling any other functions for a given serial port.
 extern "C" S500API_NEO int  __stdcall openMonitor(char* port);

//Close the serial port. It is good practice to call this function before exiting your program.
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//This function returns 1 if the serial port has been closed, and 0 if an error occurred.
extern "C" S500API_NEO int __stdcall closeMonitor(char* port);

//Get the serial number for the device. 
//The function returns an integer for the 9-digit serial number. 
//If an error occurs, the function will return 0.
extern "C" S500API_NEO int __stdcall getSerial(char* port, char * pSN, int iSize);

//Detect whether the serial port is open or not. 
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//This function returns 1 of the serial port is open, and 0 if it is not.
extern "C" S500API_NEO int __stdcall isOpen(char* port);

//Flush the device's buffer. 
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//This function returns 1 of the buffer has been flushed, and 0 if an error occurred.
//NOTE: This function is not necessary for most applications, since the buffer is flushed automatically
//when an error occurs
extern "C" S500API_NEO int __stdcall flush(char* port);

//Set the wavelength for the device. 
//Parameters include a char pointer to the name of the serial port and an integer value for the desired wavelength 
//The function returns 1 if the command was successfully sent to the device, and 0 if not.
extern "C" S500API_NEO int __stdcall setWavelength(char* port, int iwavelength);

//Get the current wavelength setting for the device. 
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//The function returns the value, in nanometers, as an integer.
//If the device is not licensed, or an error occurs, the function returns 0.
extern "C" S500API_NEO int __stdcall getWavelength(char* port);


//Get the current power reading for the device. 
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//The function returns a double type number with the reading for the current power measurement setting (dB or dBm). 
//Returns 100 if an error occurs, or if the device is not licensed.
//Returns 101 if the device is disconnected from a power supply.
extern "C" S500API_NEO double __stdcall getPower(char* port);

//Get the channel for the array device. 
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//If the device is a single channel Series 500
//the function will return 1. If the device is not licensed, or an error occurs, 
//the function will return 0.
extern "C" S500API_NEO int __stdcall getChannel(char* port);

//Get the sampling rate of the device. 
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//The function returns a char 'f' for fast or 's' for slow, 
//'e'if an error occurred, or if the device is not licensed.
extern "C" S500API_NEO char __stdcall getSampleRate(char* port);

//Set the sampling rate for the device. 
//Parameters include a char pointer string that represents the serial port. Example: "COM8" 
//and a char for the desired mode: 'f'for fast, and 's'for slow mode. 
//The function returns 1 if the command was successfully sent to the device, and 0 if not.
extern "C" S500API_NEO int __stdcall setSampleRate(char* port, char);

//Get the current power measurement mode.  
//The function returns a char 'r' for relative (dB), or 'a' for absolute (dBm). 
//If an error occurs of the device is not licensed, the function will return the char 'e'. 
extern "C" S500API_NEO char __stdcall getMode(char* port);

//Set the power measurement mode for the device. 
//The function takes a char as a parameter, 'a' for absolute power measurement(dBm) and 'r' for relative power measurement (dB). 
//The function returns 1 if the command was successfully sent to the device, and 0 if not.
extern "C" S500API_NEO int __stdcall setMode(char* port, char mode);


//get the polarization mode for the device.
//Parameter is a char pointer string that represents the serial port. Example: "COM8"
//The function returns an integer 1 for p1, and 2 for p2. 
//The function returns a 0 if an error occurs, or if the device is not a PM model.
extern "C" S500API_NEO int __stdcall getPolarization(char* port);

//set the polarization mode for the device.
//Parameters include a char pointer string that represents the serial port. Example: "COM8" 
//and an integer for the desired polarization:  1 for p1, and 2 for p2. 
//The function returns 1 if the command was successfully sent to the device, and 0 if not.
extern "C" S500API_NEO int __stdcall setPolarization(char* port, int);


//Get the battery power for the device. 
//The function returns the battery power, in mV, as an integer. 
//If the device is not licensed, or an error occurs, the function returns 0
extern "C" S500API_NEO int __stdcall getBatteryPower(char* port);


 //Set licensed file directory for the device. 
//The function takes a string as a parameter
//The function returns 1 if the command was successfully sent to the device, 0 if not.
extern "C" S500API_NEO int __stdcall setLicenseFilePath(char* port, char* pPath);

 //Get Model Number from the device. 
//The function returns length of Model Number string, 0 if error occurred
//pModel, a pointer to a buffer that recieve the Model Number.
//iSize, the maximum size of the buffer specified by pModel
extern "C" S500API_NEO int __stdcall getModel(char* port, char* pModel, int iSize);

 //Get Version information from the device. 
//The function returns length of Model Number string, 0 if error occurred
//pRevInfo, a pointer to a buffer that recieve the Model Number.
//iSize, the maximum size of the buffer specified by pModel
extern "C" S500API_NEO int __stdcall getRevInfo(char* port, char* pRevInfo, int iSize);

//Get Version information from the device. 
//The function returns length of Model Number string, 0 if error occurred
//pErrorInfo, a pointer to a buffer that recieve the Model Number.
//iSize, the maximum size of the buffer specified by pModel
extern "C" S500API_NEO int __stdcall getLastError(char* port, char* pErrorInfo, int iSize);

 //Detect whether current device is licensed or not
 //This function returns 1 if it's licensed, 0 if it's not or error occurred
extern "C" S500API_NEO int __stdcall isLicensed(char* port);
#endif